<?php
function deleteConnection($id, $checkValid = true) {
	// Prüfen ob die ID gültig ist
	if(empty($id) || !is_numeric($id) || $id == 0) {
		return array("status" => "error", "message" => "Ungültige Verweis-ID übergeben: " . $id);
	}

	$id = floor($id);

	// Prüfen ob die Buchung existiert und zu dem User gehört
	if($checkValid && !buchungValid($id)) {
		return array("status" => "error", "message" => "Diese Buchung existiert nicht oder gehört einem anderen User");
	}
	
	// Verweis löschen
	$sql_d = "DELETE FROM *PREFIX*md_fibu_connection WHERE buchung_pos=? OR buchung_neg=?";
	$res_d = query($sql_d, array($id, $id));
	if(isSqlError($res_d)) {
		return array("status" => "error", "message" => "Fehler beim Löschen des Verweises: " . getSqlError());
	}
	
	// Rückgabe alles OK
	return array("status" => "success", "message" => "");
}

function getConnectionOptions($id) {
	$data = array();
	
	// Prüfen ob die ID gültig ist
	if(empty($id) || !is_numeric($id) || $id == 0) {
		return array("status" => "error", "message" => "Ungültige Verweis-ID übergeben: " . $id);
	}

	$id = floor($id);

	// Existiert die Buchung und gehört zu diesem User?
	if(!buchungValid($id)) {
		return array("status" => "error", "message" => "Diese Buchung existiert nicht oder gehört einem anderen User");
	}
		
	// Buchungsdetails laden
	$sql_b = "SELECT * FROM *PREFIX*md_fibu_buchungen WHERE id=?";
	$res_b = query($sql_b, array($id));
	$buchung = $res_b->fetchRow();
	
	// Optionen laden (Buchungen auf andren Konten des User mit dem invertierten Betrag)
	$sql_c = "SELECT b.id AS id, k.name AS name FROM *PREFIX*md_fibu_buchungen b, *PREFIX*md_fibu_konten k WHERE b.konto=k.id AND b.betrag=? AND k.id<>? AND k.uid=?";
	$res_c = query($sql_c, array($buchung['betrag'] * -1, $buchung['konto'], getUID()));
	if(isSqlError($res_c)) {
		return array("status" => "error", "message" => "Fehler beim Laden der Optionen: " . getSqlError());
	} 
	
	$index = 0;
	while($row = $res_c->fetchRow()) {
	
		// Prüfen ob die Buchung nicht bereits verknüpft ist
		$sql_cc = "SELECT * FROM *PREFIX*md_fibu_connection WHERE buchung_neg=? OR buchung_pos=?";
		$res_cc = query($sql_cc, array($row['id'], $row['id']));
		if($res_cc->rowCount() == 0) {
		
			$data[$index] = array();
			$data[$index]["id"] = $row["id"];
			$data[$index]["konto_name"] = $row["name"];
			
			$index += 1;
		
		}
	}
	
	// Rückgabe alles OK
	return array("status" => "success", "message" => "", "data" => $data);
}

function newConnection($id1, $id2) {
	// Eingaben auf Gültigkeit prüfen
	if(empty($id1) || !is_numeric($id1) || $id1 == 0) {
		return array("status" => "error", "message" => "Ungültige ID 1 übergeben: " . $id1);
	}
	if(empty($id2) || !is_numeric($id2) || $id2 == 0) {
		return array("status" => "error", "message" => "Ungültige ID 2 übergeben: " . $id2);
	}

	$id1 = floor($id1);
	$id2 = floor($id2);

	// Prüfen ob die Buchungen existieren und zu dem User gehören
	if(!buchungValid($id1)) {
		return array("status" => "error", "message" => "Buchung 1 existiert nicht oder gehört einem anderen User");
	}
	if(!buchungValid($id2)) {
		return array("status" => "error", "message" => "Buchung 2 existiert nicht oder gehört einem anderen User");
	}
	
	// Ermitteln welches die positive Buchung ist
	$sql_b1 = "SELECT * FROM *PREFIX*md_fibu_buchungen WHERE id=? LIMIT 0,1";
	$res_b1 = query($sql_b1, array($id1));
	$buchung1 = $res_b1->fetchRow();
	$sql_b2 = "SELECT * FROM *PREFIX*md_fibu_buchungen WHERE id=? LIMIT 0,1";
	$res_b2 = query($sql_b2, array($id2));
	$buchung2 = $res_b2->fetchRow();
	
	// Prüfen ob diese Buchungen miteinander verknüpft werden können
	if($buchung1['betrag'] > 0 && $buchung2['betrag'] > 0) {
		return array("status" => "error", "message" => "Diese Buchungen haben einen identischen Betrag");
	}
	if($buchung1['betrag'] * -1 != $buchung2['betrag']) {
		return array("status" => "error", "message" => "Die Beträge dieser Buchungen passen nicht zusammen");
	}
	if($buchung1['konto'] == $buchung2['konto']) {
		return array("status" => "error", "message" => "Die Buchungen liegen auf demselben Konto");
	}
		
	// Liegen schon Verweise vor?
	$sql_cc = "SELECT * FROM *PREFIX*md_fibu_connection WHERE buchung_neg IN(?, ?) OR buchung_pos IN (?, ?)";
	$res_cc = query($sql_cc, array($id1, $id2, $id1, $id2));
	if($res_cc->rowCount() != 0) {
		return array("status" => "error", "message" => "Zu einer der Buchungen existiert bereits ein Verweis");
	}
	
	// Verknüpfung speichern
	$buchung_neg = ($buchung1['betrag'] > 0) ? $id2 : $id1;
	$buchung_pos = ($buchung1['betrag'] > 0) ? $id1 : $id2;
	
	$sql_i = "INSERT INTO *PREFIX*md_fibu_connection (`buchung_pos`, `buchung_neg`) VALUES (?, ?)";
	$res_i = query($sql_i, array($buchung_pos, $buchung_neg));
	if(isSqlError($res_i)) {
		return array("status" => "error", "message" => "Fehler beim Speichern des Verweises: " . getSqlError());
	}
	
	// Rückgabe alles OK
	return array("status" => "success", "message" => "");
}
?>